@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 """Manages logic for service accounts."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
 
 import io
@@ -59,7 +60,7 @@ def CredentialsFromAdcFile(filename):
 
 
 def CredentialsFromAdcDict(json_key):
-  """Creates credentials object from a dict of application default creds."""
+  """Creates oauth2client creds from a dict of application default creds."""
   if 'client_email' not in json_key:
     raise BadCredentialJsonFileException(
         'The .json key file is not in a valid format.')
@@ -73,6 +74,36 @@ def CredentialsFromAdcDict(json_key):
   return creds
 
 
+def CredentialsFromAdcDictGoogleAuth(json_key):
+  """Creates google-auth creds from a dict of application default creds."""
+  # Import only when necessary to decrease the startup time. Move it to
+  # global once google-auth is ready to replace oauth2client.
+  # pylint: disable=g-import-not-at-top
+  from google.oauth2 import service_account as google_auth_service_account
+  # pylint: enable=g-import-not-at-top
+
+  keys_needed = set(['client_email', 'token_uri'])
+  missing = keys_needed.difference(json_key.keys())
+
+  if missing:
+    raise BadCredentialJsonFileException(
+        'The .json key file is not in a valid format, missing field(s) {}'
+        .format(', '.join(missing)))
+
+  service_account_credentials = (
+      google_auth_service_account.Credentials.from_service_account_info)
+  creds = service_account_credentials(json_key, scopes=config.CLOUDSDK_SCOPES)
+  # The below additional fields are not natively supported in the google-auth
+  # library but are needed in gcloud:
+  # private_key, private_key_id: required by credentials deserialization;
+  # client_id: to provid backward compatibility for oauth2client. This field is
+  # used in oauth2client service account credentials.
+  creds.private_key = json_key.get('private_key')
+  creds.private_key_id = json_key.get('private_key_id')
+  creds.client_id = json_key.get('client_id')
+  return creds
+
+
 def CredentialsFromP12File(filename, account, password=None):
   """Create p12 service account credentials from given file."""
 
