@@ -25,6 +25,7 @@ import json
 from googlecloudsdk.core import exceptions
 from googlecloudsdk.core import log
 from googlecloudsdk.core.credentials import flow as c_flow
+from googlecloudsdk.core.credentials import google_auth_credentials as c_google_auth
 from googlecloudsdk.core.credentials import store as c_store
 from googlecloudsdk.core.util import files
 
@@ -39,8 +40,10 @@ DEFAULT_CREDENTIALS_DEFAULT_CLIENT_SECRET = 'd-FL95Q19q7MQmFpd7hHD0Ty'
 CLOUD_PLATFORM_SCOPE = 'https://www.googleapis.com/auth/cloud-platform'
 GOOGLE_DRIVE_SCOPE = 'https://www.googleapis.com/auth/drive'
 USER_EMAIL_SCOPE = 'https://www.googleapis.com/auth/userinfo.email'
+OPENID = 'openid'
 
 DEFAULT_SCOPES = [
+    OPENID,
     USER_EMAIL_SCOPE,
     CLOUD_PLATFORM_SCOPE
 ]
@@ -76,7 +79,9 @@ def DoInstalledAppBrowserFlowGoogleAuth(launch_browser,
   if client_id_file:
     AssertClientSecretIsInstalledType(client_id_file)
   google_auth_flow = c_flow.CreateGoogleAuthFlow(scopes, client_id_file)
-  return c_flow.RunGoogleAuthFlow(google_auth_flow, launch_browser)
+  user_creds = c_flow.RunGoogleAuthFlow(google_auth_flow, launch_browser)
+  return c_google_auth.UserCredWithReauth.FromGoogleAuthUserCredentials(
+      user_creds)
 
 
 def DoInstalledAppBrowserFlow(launch_browser, scopes, client_id_file=None,
