@@ -30,6 +30,8 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+import base64
+import binascii
 import collections
 import datetime
 import json
@@ -46,6 +48,7 @@ from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
 from googlecloudsdk.core.console import console_io
 from googlecloudsdk.core.console import progress_tracker
+from googlecloudsdk.core.util import encoding
 from googlecloudsdk.core.util import times
 import six
 
@@ -56,6 +59,9 @@ SSH_KEY_PROPAGATION_TIMEOUT_MS = 60 * 1000
 _TROUBLESHOOTING_URL = (
     'https://cloud.google.com/compute/docs/troubleshooting#ssherrors')
 
+GUEST_ATTRIBUTES_METADATA_KEY = 'enable-guest-attributes'
+SUPPORTED_HOSTKEY_TYPES = ['ssh-rsa', 'ssh-ed25519', 'ecdsa-sha2-nistp256']
+
 
 class UnallocatedIPAddressError(core_exceptions.Error):
   """An exception to be raised when a network interface's IP address is yet
@@ -255,6 +261,25 @@ def _GetSSHKeysFromMetadata(metadata):
   return ssh_keys, ssh_legacy_keys
 
 
+def _MetadataHasGuestAttributesEnabled(metadata):
+  """Returns true if the metadata has 'enable-guest-attributes' set to 'true'.
+
+  Args:
+    metadata: Instance or Project metadata
+
+  Returns:
+    True if Enabled, False if Disabled, None if key is not present.
+  """
+  if not (metadata and metadata.items):
+    return None
+  matching_values = [item.value for item in metadata.items
+                     if item.key == GUEST_ATTRIBUTES_METADATA_KEY]
+
+  if not matching_values:
+    return None
+  return matching_values[0].lower() == 'true'
+
+
 def _SSHKeyExpiration(ssh_key):
   """Returns a datetime expiration time for an ssh key entry from metadata.
 
@@ -488,17 +513,35 @@ class BaseSSHHelper(object):
               project=project or
               properties.VALUES.core.project.Get(required=True),))])[0]
 
-  def GetHostKeysFromGuestAttributes(self, client, instance_ref):
+  def GetHostKeysFromGuestAttributes(self, client, instance_ref,
+                                     instance=None, project=None):
     """Get host keys from guest attributes.
 
     Args:
       client: The compute client.
       instance_ref: The instance object.
+      instance: The object representing the instance we are connecting to. If
+        either project or instance is None, metadata won't be checked to
+        determine if Guest Attributes are enabled.
+      project: The object representing the current project. If either project
+        or instance is None, metadata won't be checked to determine if
+        Guest Attributes are enabled.
 
     Returns:
       A dictionary of host keys, with the type as the key and the host key
-      as the value.
+      as the value, or None if Guest Attributes is not enabled.
     """
+    if instance and project:
+      # Instance metadata has priority.
+      guest_attributes_enabled = _MetadataHasGuestAttributesEnabled(
+          instance.metadata)
+      if guest_attributes_enabled is None:
+        project_metadata = project.commonInstanceMetadata
+        guest_attributes_enabled = _MetadataHasGuestAttributesEnabled(
+            project_metadata)
+      if not guest_attributes_enabled:
+        return None
+
     requests = [(client.apitools_client.instances,
                  'GetGuestAttributes',
                  client.messages.ComputeInstancesGetGuestAttributesRequest(
@@ -520,8 +563,21 @@ class BaseSSHHelper(object):
 
     if hostkeys is not None:
       for item in hostkeys.queryValue.items:
-        if item.namespace == 'hostkeys':
-          hostkey_dict[item.key] = item.value
+        if (item.namespace == 'hostkeys'
+            and item.key in SUPPORTED_HOSTKEY_TYPES):
+          # Truncate key value at any whitespace (newlines specifically can
+          # be a security issue).
+          key_value = item.value.split()[0]
+
+          # Verify that key value is a base64 string
+          try:
+            decoded_key = base64.b64decode(key_value)
+            encoded_key = encoding.Decode(base64.b64encode(decoded_key))
+          except (TypeError, binascii.Error):
+            encoded_key = ''
+
+          if key_value == encoded_key:
+            hostkey_dict[item.key] = key_value
 
     return hostkey_dict
 
