@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,18 +15,22 @@
 """Utilities for dataproc workflow template add-job CLI."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
-from googlecloudsdk.api_lib.dataproc import util
+
 from googlecloudsdk.calliope import arg_parsers
+from googlecloudsdk.command_lib.dataproc import flags
 from googlecloudsdk.command_lib.util.args import labels_util
 
+# Fields to filter on export.
+TEMPLATE_FIELDS = ['id', 'name', 'version', 'createTime', 'updateTime']
 
-def AddWorkflowTemplatesArgs(parser):
+
+def AddWorkflowTemplatesArgs(parser, api_version):
   """Register flags for this command."""
   labels_util.AddCreateLabelsFlags(parser)
-  parser.add_argument(
-      '--workflow-template', required=True,
-      help='The dataproc workflow template ID.')
+  flags.AddTemplateResourceArg(
+      parser, 'add job to', api_version, positional=False)
 
   parser.add_argument(
       '--step-id',
@@ -41,6 +45,19 @@ def AddWorkflowTemplatesArgs(parser):
       help='(Optional) List of step IDs to start this job after.')
 
 
+def AddDagTimeoutFlag(parser, is_required):
+  parser.add_argument(
+      '--dag-timeout',
+      type=arg_parsers.Duration(),
+      required=is_required,
+      help="""\
+          The duration for which a DAG of jobs can run before being
+          auto-cancelled, such as "10m" or "16h".
+          See $ gcloud topic datetimes for information on duration formats.
+          """,
+      hidden=True)
+
+
 def CreateWorkflowTemplateOrderedJob(args, dataproc):
   """Create an ordered job for workflow template."""
   ordered_job = dataproc.messages.OrderedJob(stepId=args.step_id)
@@ -51,7 +68,7 @@ def CreateWorkflowTemplateOrderedJob(args, dataproc):
 
 def AddJobToWorkflowTemplate(args, dataproc, ordered_job):
   """Add an ordered job to the workflow template."""
-  template = util.ParseWorkflowTemplates(args.workflow_template, dataproc)
+  template = args.CONCEPTS.workflow_template.Parse()
 
   workflow_template = dataproc.GetRegionsWorkflowTemplate(
       template, args.version)
@@ -71,3 +88,9 @@ def ConfigureOrderedJob(messages, job, args):
   # Parse labels (if present)
   job.labels = labels_util.ParseCreateArgs(
       args, messages.OrderedJob.LabelsValue)
+
+
+def Filter(template):
+  for field in TEMPLATE_FIELDS:
+    if field in template:
+      del template[field]
