@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,13 +15,25 @@
 """Provides common arguments for the Spanner command surface."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 import itertools
 
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.util import completers
 
 
+class BackupCompleter(completers.ListCommandCompleter):
+
+  def __init__(self, **kwargs):
+    super(BackupCompleter, self).__init__(
+        collection='spanner.projects.instances.backups',
+        list_command='spanner backups list --uri',
+        flags=['instance'],
+        **kwargs)
+
+
 class DatabaseCompleter(completers.ListCommandCompleter):
 
   def __init__(self, **kwargs):
@@ -75,7 +87,7 @@ class DatabaseSessionCompleter(completers.ListCommandCompleter):
   def __init__(self, **kwargs):
     super(DatabaseSessionCompleter, self).__init__(
         collection='spanner.projects.instances.databases.sessions',
-        list_command='beta spanner databases sessions list --uri',
+        list_command='spanner databases sessions list --uri',
         flags=['database', 'instance'],
         **kwargs)
 
@@ -96,6 +108,14 @@ def Database(positional=True,
         help=text)
 
 
+def Backup(positional=True, required=True, text='Cloud Spanner backup ID.'):
+  if positional:
+    return base.Argument('backup', completer=BackupCompleter, help=text)
+  else:
+    return base.Argument(
+        '--backup', required=required, completer=BackupCompleter, help=text)
+
+
 def Ddl(required=False, help_text=''):
   return base.Argument(
       '--ddl',
@@ -119,7 +139,10 @@ def Config(required=True):
       '--config',
       completer=InstanceConfigCompleter,
       required=required,
-      help='Instance config for the instance.')
+      help='Instance configuration defines the geographic placement and '
+      'replication of the databases in that instance. Available '
+      'configurations can be found by running '
+      '"gcloud spanner instance-configs list"')
 
 
 def Description(required=True):
