@@ -269,7 +269,7 @@ class Keys(object):
       # which are relatively inconsequential.
       decoded_key = key_string.strip()
       if isinstance(key_string, six.binary_type):
-        decoded_key = decoded_key.decode('utf8', 'replace')
+        decoded_key = decoded_key.decode('utf-8', 'replace')
       parts = decoded_key.split(' ', 2)
       if len(parts) < 2:
         raise InvalidKeyError('Public key [{}] is invalid.'.format(key_string))
@@ -766,7 +766,8 @@ def CheckForOsloginAndGetUser(instance, project, requested_user, public_key,
         'OS Login is enabled on Instance/Project, but is not available '
         'in the {0} version of gcloud.'.format(release_track.id))
     return requested_user, use_oslogin
-  user_email = properties.VALUES.core.account.Get()
+  user_email = (properties.VALUES.auth.impersonate_service_account.Get()
+                or properties.VALUES.core.account.Get())
 
   # Check to see if public key is already in profile and POSIX information
   # exists associated with the project. If either are not set, import an SSH
