@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2013 Google Inc. All Rights Reserved.
+# Copyright 2013 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 """A simple auth command to bootstrap authentication with oauth2."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
 
 import getpass
@@ -98,7 +99,13 @@ class ActivateServiceAccount(base.SilentCommand):
 
     file_content, is_json = _IsJsonFile(args.key_file)
     if is_json:
-      cred = auth_service_account.CredentialsFromAdcDict(file_content)
+      use_google_auth = (not properties.VALUES.auth.
+                         disable_activate_service_account_google_auth.GetBool())
+      if use_google_auth:
+        cred = auth_service_account.CredentialsFromAdcDictGoogleAuth(
+            file_content)
+      else:
+        cred = auth_service_account.CredentialsFromAdcDict(file_content)
       if args.password_file or args.prompt_for_password:
         raise c_exc.InvalidArgumentException(
             '--password-file',
