@@ -21,7 +21,6 @@ from __future__ import unicode_literals
 from googlecloudsdk.api_lib.cloudbuild import cloudbuild_util
 from googlecloudsdk.api_lib.cloudbuild import trigger_config as trigger_utils
 from googlecloudsdk.calliope import base
-from googlecloudsdk.calliope import exceptions as c_exceptions
 from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
 from googlecloudsdk.core import resources
@@ -30,6 +29,19 @@ from googlecloudsdk.core import resources
 class CreateGitHub(base.CreateCommand):
   """Create a build trigger for a GitHub repository."""
 
+  detailed_help = {
+      'EXAMPLES':
+          """\
+            To create a push trigger for all branches:
+
+              $ {command} --repo-owner="GoogleCloudPlatform" --repo-name="cloud-builders" --branch-pattern=".*" --build-config="cloudbuild.yaml"
+
+            To create a pull request trigger for master:
+
+              $ {command} --repo-owner="GoogleCloudPlatform" --repo-name="cloud-builders" --pull-request-pattern="^master$" --build-config="cloudbuild.yaml"
+          """,
+  }
+
   @staticmethod
   def Args(parser):
     """Register flags for this command.
@@ -39,26 +51,7 @@ class CreateGitHub(base.CreateCommand):
         to capture some information, but behaves like an ArgumentParser.
     """
 
-    parser.display_info.AddFormat("""
-          table(
-            name,
-            createTime.date('%Y-%m-%dT%H:%M:%S%Oz', undefined='-'),
-            status
-          )
-        """)
-
-    # Allow trigger config to be specified on the command line or file
-    trigger_config = parser.add_mutually_exclusive_group(required=True)
-    trigger_config.add_argument(
-        '--trigger-config',
-        help='Path to Build Trigger config file. See https://cloud.google.com/cloud-build/docs/api/reference/rest/v1/projects.triggers#BuildTrigger',
-        metavar='PATH',
-    )
-
-    # Trigger configuration
-    flag_config = trigger_config.add_argument_group(
-        help='Flag based trigger configuration')
-    flag_config.add_argument('--description', help='Build trigger description.')
+    flag_config = trigger_utils.AddTriggerArgs(parser)
     flag_config.add_argument(
         '--repo-owner', help='Owner of the GitHub Repository.', required=True)
 
@@ -71,6 +64,7 @@ class CreateGitHub(base.CreateCommand):
     pr_config.add_argument(
         '--pull-request-pattern',
         metavar='REGEX',
+        required=True,
         help="""\
 A regular expression specifying which base git branch to match for
 pull request events.
@@ -90,17 +84,27 @@ RE2 and described at https://github.com/google/re2/wiki/Syntax.
     trigger_utils.AddBuildConfigArgs(flag_config)
 
   def ParseTriggerFromFlags(self, args):
+    """Parses command line arguments into a build trigger.
+
+    Args:
+      args: An argparse arguments object.
+
+    Returns:
+      A build trigger object.
+
+    Raises:
+      RequiredArgumentException: If comment_control is defined but
+      pull_request_pattern isn't.
+    """
     project = properties.VALUES.core.project.Get(required=True)
     messages = cloudbuild_util.GetMessagesModule()
-    trigger = messages.BuildTrigger()
-    trigger.description = args.description
+
+    trigger, done = trigger_utils.ParseTriggerArgs(args, messages)
+    if done:
+      return trigger
+
     # GitHub config
     gh = messages.GitHubEventsConfig(owner=args.repo_owner, name=args.repo_name)
-
-    if args.comment_control and not args.pull_request_pattern:
-      raise c_exceptions.RequiredArgumentException(
-          '--comment-control',
-          '--comment-control must be specified with --pull-request-pattern')
     if args.pull_request_pattern:
       gh.pullRequest = messages.PullRequestFilter(
           branch=args.pull_request_pattern)
@@ -112,27 +116,9 @@ RE2 and described at https://github.com/google/re2/wiki/Syntax.
           branch=args.branch_pattern, tag=args.tag_pattern)
     trigger.github = gh
 
-    # Build Config
-    if args.build_config:
-      trigger.filename = args.build_config
-      trigger.substitutions = cloudbuild_util.EncodeTriggerSubstitutions(
-          args.substitutions, messages)
-    if args.dockerfile:
-      image = args.dockerfile_image if args.dockerfile_image else 'gcr.io/%s/github.com/%s/%s:$COMMIT_SHA' % (
-          project, args.repo_owner, args.repo_name)
-      trigger.build = messages.Build(steps=[
-          messages.BuildStep(
-              name='gcr.io/cloud-builders/docker',
-              dir=args.dockerfile_dir,
-              args=['build', '-t', image, '-f', args.dockerfile, '.'],
-          )
-      ])
-
-    # Include/Exclude files
-    if args.included_files:
-      trigger.includedFiles = args.included_files
-    if args.ignored_files:
-      trigger.ignoredFiles = args.ignored_files
+    default_image = 'gcr.io/%s/github.com/%s/%s:$COMMIT_SHA' % (
+        project, args.repo_owner, args.repo_name)
+    trigger_utils.ParseBuildConfigArgs(trigger, args, messages, default_image)
 
     return trigger
 
@@ -150,15 +136,7 @@ RE2 and described at https://github.com/google/re2/wiki/Syntax.
     client = cloudbuild_util.GetClientInstance()
     messages = cloudbuild_util.GetMessagesModule()
 
-    trigger = messages.BuildTrigger()
-    if args.trigger_config:
-      trigger = cloudbuild_util.LoadMessageFromPath(
-          path=args.trigger_config,
-          msg_type=messages.BuildTrigger,
-          msg_friendly_name='build trigger config',
-          skip_camel_case=['substitutions'])
-    else:
-      trigger = self.ParseTriggerFromFlags(args)
+    trigger = self.ParseTriggerFromFlags(args)
 
     # Send the Create request
     project = properties.VALUES.core.project.Get(required=True)
