@@ -52,8 +52,10 @@ class SetSchedulingInstances(base.SilentCommand):
         help="""\
         The instances will be restarted if they are terminated by Compute
         Engine.  This does not affect terminations performed by the user.
+        This option is mutually exclusive with --preemptible.
         """)
 
+    flags.AddPreemptibleVmArgs(parser)
     flags.AddMaintenancePolicyArgs(parser)
     sole_tenancy_flags.AddNodeAffinityFlagToParser(parser, is_update=True)
     flags.INSTANCE_ARG.AddArgument(parser)
@@ -72,11 +74,17 @@ class SetSchedulingInstances(base.SilentCommand):
 
     scheduling_options.automaticRestart = args.restart_on_failure
 
+    if args.IsSpecified('preemptible'):
+      scheduling_options.preemptible = args.preemptible
+
+    cleared_fields = []
+
     if support_min_node_cpu:
       if args.IsSpecified('min_node_cpu'):
         scheduling_options.minNodeCpus = int(args.min_node_cpu)
       elif args.IsSpecified('clear_min_node_cpu'):
         scheduling_options.minNodeCpus = None
+        cleared_fields.append('minNodeCpus')
 
     if args.IsSpecified('maintenance_policy'):
       scheduling_options.onHostMaintenance = (
@@ -90,15 +98,17 @@ class SetSchedulingInstances(base.SilentCommand):
       scheduling_options.nodeAffinities = affinities
     elif args.IsSpecified('clear_node_affinities'):
       scheduling_options.nodeAffinities = []
+      cleared_fields.append('nodeAffinities')
 
-    request = client.messages.ComputeInstancesSetSchedulingRequest(
-        instance=instance_ref.Name(),
-        project=instance_ref.project,
-        scheduling=scheduling_options,
-        zone=instance_ref.zone)
+    with holder.client.apitools_client.IncludeFields(cleared_fields):
+      request = client.messages.ComputeInstancesSetSchedulingRequest(
+          instance=instance_ref.Name(),
+          project=instance_ref.project,
+          scheduling=scheduling_options,
+          zone=instance_ref.zone)
 
-    return client.MakeRequests([(client.apitools_client.instances,
-                                 'SetScheduling', request)])
+      return client.MakeRequests([(client.apitools_client.instances,
+                                   'SetScheduling', request)])
 
   def Run(self, args):
     return self._Run(args)
@@ -120,7 +130,10 @@ class SetSchedulingInstancesBeta(SetSchedulingInstances):
         help="""\
         The instances will be restarted if they are terminated by Compute
         Engine.  This does not affect terminations performed by the user.
+        This option is mutually exclusive with --preemptible.
         """)
+
+    flags.AddPreemptibleVmArgs(parser)
     flags.AddMaintenancePolicyArgs(parser)
     sole_tenancy_flags.AddNodeAffinityFlagToParser(parser, is_update=True)
     flags.INSTANCE_ARG.AddArgument(parser)
@@ -146,8 +159,10 @@ class SetSchedulingInstancesAlpha(SetSchedulingInstancesBeta):
         help="""\
         The instances will be restarted if they are terminated by Compute
         Engine.  This does not affect terminations performed by the user.
+        This option is mutually exclusive with --preemptible.
         """)
 
+    flags.AddPreemptibleVmArgs(parser)
     # Deprecated in Alpha
     flags.AddMaintenancePolicyArgs(parser, deprecate=True)
     sole_tenancy_flags.AddNodeAffinityFlagToParser(parser, is_update=True)
