@@ -22,7 +22,8 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA,
+                    base.ReleaseTrack.BETA)
 class Gameservices(base.Group):
   """Managed Cloud Game Services."""
   category = base.SOLUTIONS_CATEGORY
