@@ -29,14 +29,15 @@ from googlecloudsdk.command_lib.run import pretty_print
 from googlecloudsdk.command_lib.run import resource_args
 from googlecloudsdk.command_lib.run import serverless_operations
 from googlecloudsdk.command_lib.run import stages
+from googlecloudsdk.command_lib.run import traffic_printer
 from googlecloudsdk.command_lib.util.concepts import concept_parsers
 from googlecloudsdk.command_lib.util.concepts import presentation_specs
 from googlecloudsdk.core.console import progress_tracker
+from googlecloudsdk.core.resource import resource_printer
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA,
-                    base.ReleaseTrack.BETA,
-                    base.ReleaseTrack.ALPHA)
+                    base.ReleaseTrack.BETA)
 class AdjustTraffic(base.Command):
   """Adjust the trafic assignments for a Cloud Run service."""
 
@@ -75,8 +76,8 @@ class AdjustTraffic(base.Command):
          """,
   }
 
-  @staticmethod
-  def Args(parser):
+  @classmethod
+  def CommonArgs(cls, parser):
     service_presentation = presentation_specs.ResourcePresentationSpec(
         'SERVICE',
         resource_args.GetServiceResourceSpec(prompt=True),
@@ -84,21 +85,12 @@ class AdjustTraffic(base.Command):
         required=True,
         prefixes=False)
     flags.AddAsyncFlag(parser)
-    flags.AddUpdateTrafficFlags(parser)
+    flags.AddUpdateTrafficFlags(parser, cls.ReleaseTrack())
     concept_parsers.ConceptParser([service_presentation]).AddToParser(parser)
 
-  def _SetFormat(self, args):
-    """Set display format for output.
-
-    Args:
-      args: Namespace, the args namespace
-    """
-    columns = [
-        'displayPercent:label=TRAFFIC',
-        'displayRevisionId:label=REVISION',
-    ]
-    args.GetDisplayInfo().AddFormat(
-        'table({})'.format(','.join(columns)))
+  @classmethod
+  def Args(cls, parser):
+    cls.CommonArgs(parser)
 
   def Run(self, args):
     """Update the traffic split for the service.
@@ -109,6 +101,13 @@ class AdjustTraffic(base.Command):
     Returns:
       List of traffic.TrafficTargetStatus instances reflecting the change.
     """
+    # TODO(b/143898356) Begin code that should be in Args
+    resource_printer.RegisterFormatter(
+        traffic_printer.TRAFFIC_PRINTER_FORMAT,
+        traffic_printer.TrafficPrinter)
+    args.GetDisplayInfo().AddFormat('traffic')
+    # End code that should be in Args
+
     conn_context = connection_context.GetConnectionContext(
         args, flags.Product.RUN, self.ReleaseTrack())
     service_ref = flags.GetService(args)
@@ -118,8 +117,6 @@ class AdjustTraffic(base.Command):
       raise exceptions.NoConfigurationChangeError(
           'No traffic configuration change requested.')
 
-    self._SetFormat(args)
-
     is_managed = flags.GetPlatform() == flags.PLATFORM_MANAGED
     with serverless_operations.Connect(conn_context) as client:
       deployment_stages = stages.UpdateTrafficStages()
@@ -137,7 +134,8 @@ class AdjustTraffic(base.Command):
               serv.spec_traffic,
               serv.status_traffic,
               is_managed,
-              serv.status.latestReadyRevisionName)
+              serv.status.latestReadyRevisionName,
+              serv.status.url)
           display.Displayer(
               self, args, resources,
               display_info=args.GetDisplayInfo()).Display()
@@ -151,5 +149,17 @@ class AdjustTraffic(base.Command):
           serv.spec_traffic,
           serv.status_traffic,
           is_managed,
-          serv.status.latestReadyRevisionName)
+          serv.status.latestReadyRevisionName,
+          serv.status.url)
       return resources
+
+
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class AlphaAdjustTraffic(AdjustTraffic):
+  """Adjust the traffic assignments for a Cloud Run service."""
+
+  @classmethod
+  def Args(cls, parser):
+    cls.CommonArgs(parser)
+    flags.AddTrafficTagsFlags(parser)
+
